@@ -6,9 +6,9 @@ import json
 import logging
 import re
 import urllib.parse
-from dataclasses import dataclass, field
+from dataclasses import InitVar, dataclass, field
 from pathlib import Path
-from typing import Any, Dict, List, Mapping, Optional, Tuple, Union, cast
+from typing import Any, Dict, List, Mapping, Optional, Set, Tuple, Union, cast
 
 import defusedxml.ElementTree as ET
 import fire
@@ -29,9 +29,11 @@ DEFAULT_METHOD = "POST"
 DEFAULT_PROFILE = "default"
 DEFAULT_REGION = "eu-west-2"
 DEFAULT_VERSION = datetime.date.today().strftime("%Y-%m-%d")
-DEFAULT_AUTHENTICATION_METHOD = "accesskey"
+
+DEFAULT_HOST = "outscale.com"
+
 METHODS_SUPPORTED = {"GET", "POST"}
-SDK_VERSION = "1.7.0"
+SDK_VERSION = "1.8.0"
 SSL_VERIFY = True
 SUCCESS_CODES = {200, 201, 202, 203, 204}
 USER_AGENT = "osc_sdk " + SDK_VERSION
@@ -43,6 +45,31 @@ CallParameters = Dict[str, Any]
 EncodedCallParameters = Optional[str]
 Headers = Tuple[str, str, Dict[str, str]]
 
+NO_AUTH_CALLS: Dict[str, Set[str]] = {
+    "api": {
+        "ReadFlexibleGpuCatalog",
+        "ReadLocations",
+        "ReadNetAccessPointServices",
+        "ReadProductTypes",
+        "ReadPublicIpRanges",
+        "ReadRegions",
+        "ReadVmTypes",
+        "ResetAccountPassword",
+        "SendResetPasswordEmail",
+    },
+    "icu": {
+        "AuthenticateAccount",
+        "ResetAccountPassword",
+        "SendResetPasswordEmail",
+        "ReadPublicCatalog",
+        "CheckSignature",
+    },
+    "fcu": {
+        "DescribeRegions",
+        "ReadPublicIpRanges",
+    },
+}
+
 
 class Configuration(TypedDict):
     method: str
@@ -74,7 +101,7 @@ class Tag(TypedDict):
 
 @dataclass
 class OscApiException(Exception):
-    http_response: Response
+    http_response: InitVar[Response]
 
     status_code: int = field(init=False)
     error_code: Optional[str] = field(default=None, init=False)
@@ -148,7 +175,7 @@ class ApiCall:
     profile: str = DEFAULT_PROFILE
     login: Optional[str] = None
     password: Optional[str] = None
-    authentication_method: str = DEFAULT_AUTHENTICATION_METHOD
+    authentication_method: Optional[str] = None
 
     API_NAME: str = field(default="", init=False)
     CONTENT_TYPE = "application/x-www-form-urlencoded"
@@ -160,61 +187,46 @@ class ApiCall:
     date: Optional[str] = field(default=None, init=False)
     datestamp: Optional[str] = field(default=None, init=False)
 
-    method: str = field(default="", init=False)
-    endpoint: str = field(default="", init=False)
-    host: str = field(default="", init=False)
-    access_key: Optional[str] = field(default=None, init=False)
-    secret_key: Optional[str] = field(default=None, init=False)
-    version: str = field(default=DEFAULT_VERSION, init=False)
-    protocol: str = field(default="", init=False)
-    region: str = field(default=DEFAULT_REGION, init=False)
-    ssl_verify: bool = field(default=SSL_VERIFY, init=False)
-    client_certificate: Optional[str] = field(default=None, init=False)
+    method: str = DEFAULT_METHOD
+    endpoint: str = ""
+    host: str = ""
+    access_key: Optional[str] = None
+    secret_key: Optional[str] = None
+    version: str = DEFAULT_VERSION
+    https: bool = True
+    protocol: str = ""
+    region_name: str = DEFAULT_REGION
+    ssl_verify: bool = SSL_VERIFY
+    client_certificate: Optional[str] = None
 
     def __post_init__(self):
         if not self.API_NAME:
             raise RuntimeError("API_NAME is required and should not be empty")
 
-        self.setup_profile_options(self.profile)
-        self.check_authentication_options()
-
-    def setup_profile_options(self, profile: str):
-        conf = get_conf(profile)
-
-        self.method = conf.get("method", DEFAULT_METHOD)
         if self.method not in METHODS_SUPPORTED:
             raise Exception(
                 f"Wrong method {self.method}. Supported: {METHODS_SUPPORTED}."
             )
 
-        self.access_key = conf.get("access_key")
-        self.secret_key = conf.get("secret_key")
-        self.version = conf.get("version", DEFAULT_VERSION)
-        self.protocol = "https" if conf.get("https", False) else "http"
-        self.region = conf.get("region_name", DEFAULT_REGION)
-        self.ssl_verify = conf.get("ssl_verify", SSL_VERIFY)
-        self.client_certificate = conf.get("client_certificate")
+        self.protocol = "https" if self.https else "http"
 
-        endpoint = conf.get("endpoint")
-        host = conf.get("host", "")
-        if host and not endpoint:
-            endpoint = ".".join([self.API_NAME, self.region, host])
+        if self.host and not self.endpoint:
+            self.endpoint = ".".join([self.API_NAME, self.region_name, self.host])
 
-        if not endpoint:
+        if not self.endpoint:
             raise RuntimeError("No endpoint found")
 
-        parsed_url = urllib.parse.urlparse(endpoint)
+        parsed_url = urllib.parse.urlparse(self.endpoint)
         if parsed_url.scheme:
-            self.endpoint = endpoint
             self.host = parsed_url.netloc
         else:
-            self.endpoint = f"{self.protocol}://{endpoint}"
-            self.host = endpoint
+            self.host = self.endpoint
+            self.endpoint = f"{self.protocol}://{self.endpoint}"
 
     def check_authentication_options(self):
-        if self.authentication_method not in {"accesskey", "password"}:
+        if self.authentication_method not in {"accesskey", "password", "none"}:
             raise RuntimeError(
-                "Unsupported authentication method (accesskey or password)"
+                "Unsupported authentication method (accesskey, password or none)"
             )
         if self.authentication_method == "accesskey":
             if self.access_key is None:
@@ -251,7 +263,12 @@ class ApiCall:
         if not self.secret_key:
             raise RuntimeError("Secret key is needed to authorize call")
 
-        credentials = [self.datestamp, self.region, self.API_NAME, self.REQUEST_TYPE]
+        credentials = [
+            self.datestamp,
+            self.region_name,
+            self.API_NAME,
+            self.REQUEST_TYPE,
+        ]
         credential_scope = "/".join(credentials)
         string_to_sign = "\n".join(
             [
@@ -314,6 +331,14 @@ class ApiCall:
         # Calculate request params
         request_params = self.get_parameters(data=kwargs)
 
+        if self.authentication_method is None:
+            if call_need_auth(self.API_NAME, call):
+                self.authentication_method = "accesskey"
+            else:
+                self.authentication_method = "none"
+
+        self.check_authentication_options()
+
         if self.authentication_method == "password":
             request_params.update(self.get_password_params())
 
@@ -481,6 +506,14 @@ class JsonApiCall(ApiCall):
 
         request_params = self.get_parameters(kwargs, call)
 
+        if self.authentication_method is None:
+            if call_need_auth(self.API_NAME, call):
+                self.authentication_method = "accesskey"
+            else:
+                self.authentication_method = "none"
+
+        self.check_authentication_options()
+
         if self.authentication_method == "password":
             request_params.update(self.get_password_params())
 
@@ -657,20 +690,40 @@ def get_conf(profile: str) -> Configuration:
     if not conf_path:
         raise RuntimeError("No configuration file found in home folder")
 
-    conf = cast(Mapping[str, Configuration], json.loads(conf_path.read_text()))
+    json_profiles = json.loads(conf_path.read_text())
+    # convert region to region_name in json to fit Mapping
+    for v in json_profiles:
+        json_profile = json_profiles[v]
+        if "region" in json_profile:
+
+            # use default stuffs only when "region" is use
+            # to keep region_name format retrocompatible
+            if not "host" in json_profile and not "endpoint" in json_profile:
+                json_profile["host"] = DEFAULT_HOST
+            if not "https" in json_profile:
+                json_profile["https"] = True
+
+            if not "region_name" in json_profile:
+                json_profile["region_name"] = json_profile["region"]
+            del json_profile["region"]
+    conf = cast(Mapping[str, Configuration], json_profiles)
     try:
         return conf[profile]
     except KeyError:
         raise RuntimeError(f"Profile {profile} not found in configuration file")
 
 
+def call_need_auth(service: str, call: str) -> bool:
+    return call not in NO_AUTH_CALLS.get(service, set())
+
+
 def api_connect(
     service: str,
     call: str,
     profile: str = DEFAULT_PROFILE,
     login: Optional[str] = None,
     password: Optional[str] = None,
-    authentication_method: str = DEFAULT_AUTHENTICATION_METHOD,
+    authentication_method: Optional[str] = None,
     **kwargs: CallParameters,
 ):
     calls = {
@@ -682,7 +735,10 @@ def api_connect(
         "lbu": LbuCall,
         "okms": OKMSCall,
     }
-    handler = calls[service](profile, login, password, authentication_method)
+
+    handler = calls[service](
+        profile, login, password, authentication_method, **get_conf(profile)
+    )
     handler.make_request(call, **kwargs)
     if handler.response:
         print(json.dumps(handler.response, indent=4))
